=== modified file 'drizzled/session.h'
--- drizzled/session.h	2011-01-19 18:03:32 +0000
+++ drizzled/session.h	2011-01-24 04:10:04 +0000
@@ -553,6 +553,11 @@
     return client;
   }
 
+  plugin::Client *getClient() const
+  {
+    return client;
+  }
+
   plugin::Scheduler *scheduler; /**< Pointer to scheduler object */
   void *scheduler_arg; /**< Pointer to the optional scheduler argument */
 

=== modified file 'drizzled/statement.h'
--- drizzled/statement.h	2011-01-22 07:05:32 +0000
+++ drizzled/statement.h	2011-01-24 04:10:04 +0000
@@ -62,6 +62,11 @@
     return _session;
   }
 
+  Session *getSession() const
+  {
+    return _session;
+  }
+
   virtual bool isShow() { return false; }
 
 private:

=== modified file 'drizzled/statement/catalog.cc'
--- drizzled/statement/catalog.cc	2011-01-13 05:06:32 +0000
+++ drizzled/statement/catalog.cc	2011-01-24 04:10:04 +0000
@@ -41,6 +41,9 @@
   if (not authorized())
     return false;
 
+  if (not perform())
+    return false;
+
   return true;
 }
 

=== modified file 'drizzled/statement/catalog.h'
--- drizzled/statement/catalog.h	2011-01-13 02:08:31 +0000
+++ drizzled/statement/catalog.h	2011-01-24 04:10:04 +0000
@@ -37,7 +37,8 @@
 public:
   Catalog(Session *in_session, drizzled::lex_string_t &arg);
 
-  virtual bool authorized()= 0;
+  virtual bool authorized() const= 0;
+  virtual bool perform() const= 0;
 
   bool execute();
 

=== modified file 'drizzled/statement/catalog/create.cc'
--- drizzled/statement/catalog/create.cc	2011-01-13 02:08:31 +0000
+++ drizzled/statement/catalog/create.cc	2011-01-24 04:10:04 +0000
@@ -21,6 +21,9 @@
 #include "config.h"
 
 #include <drizzled/statement/catalog.h>
+#include <drizzled/plugin/client.h>
+#include <drizzled/session.h>
+#include <drizzled/plugin/catalog.h>
 
 namespace drizzled
 {
@@ -36,12 +39,23 @@
 {
 }
 
-bool Create::authorized()
+bool Create::authorized() const
 {
+  if (getSession()->getClient()->isConsole())
+  {
+    return true;
+  }
+
   my_error(ER_CATALOG_CANNOT_CREATE_PERMISSION, identifier());
+
   return false;
 }
 
+bool Create::perform() const
+{
+  return plugin::Catalog::create(identifier());
+}
+
 } /* namespace catalog */
 } /* namespace statement */
 } /* namespace drizzled */

=== modified file 'drizzled/statement/catalog/create.h'
--- drizzled/statement/catalog/create.h	2011-01-13 02:08:31 +0000
+++ drizzled/statement/catalog/create.h	2011-01-24 04:10:04 +0000
@@ -35,7 +35,8 @@
 {
 public:
   Create(Session *in_session, drizzled::lex_string_t &arg);
-  bool authorized();
+  bool authorized() const;
+  bool perform() const;
 };
 
 } /* namespace catalog */

=== modified file 'drizzled/statement/catalog/drop.cc'
--- drizzled/statement/catalog/drop.cc	2011-01-13 02:08:31 +0000
+++ drizzled/statement/catalog/drop.cc	2011-01-24 04:10:04 +0000
@@ -21,6 +21,10 @@
 #include "config.h"
 
 #include <drizzled/statement/catalog.h>
+#include <drizzled/plugin/client.h>
+#include <drizzled/session.h>
+
+#include <drizzled/plugin/catalog.h>
 
 namespace drizzled
 {
@@ -36,12 +40,22 @@
 {
 }
 
-bool Drop::authorized()
+bool Drop::authorized() const
 {
+  if (getSession()->getClient()->isConsole())
+  {
+    return true;
+  }
+
   my_error(ER_CATALOG_CANNOT_DROP_PERMISSION, identifier());
   return false;
 }
 
+bool Drop::perform() const
+{
+  return plugin::Catalog::drop(identifier::Catalog(identifier()));
+}
+
 } /* namespace catalog */
 } /* namespace statement */
 } /* namespace drizzled */

=== modified file 'drizzled/statement/catalog/drop.h'
--- drizzled/statement/catalog/drop.h	2011-01-13 02:08:31 +0000
+++ drizzled/statement/catalog/drop.h	2011-01-24 04:10:04 +0000
@@ -34,7 +34,8 @@
 {
 public:
   Drop(Session *in_session, drizzled::lex_string_t &arg);
-  bool authorized();
+  bool authorized() const;
+  bool perform() const;
 };
 
 } /* namespace catalog */

=== modified file 'plugin/console/console.cc'
--- plugin/console/console.cc	2011-01-22 07:05:32 +0000
+++ plugin/console/console.cc	2011-01-24 04:10:04 +0000
@@ -133,9 +133,10 @@
     }
     while (cin.eof() == false && cin.fail() == true);
 
-    if ((*packet_length == 1 && cin.eof() == true) ||
-        !strncasecmp(*packet + 1, "quit", 4) ||
-        !strncasecmp(*packet + 1, "exit", 4))
+    if ((*packet_length == 1 && cin.eof() == true) or
+        not strncasecmp(*packet + 1, "quit", 4) or
+        not strncasecmp(*packet + 1, "exit", 4) or
+        not strncasecmp(*packet + 1, "shutdown", sizeof("shutdown") -1))
     {
       is_dead= true;
       *packet_length= 1;
@@ -363,16 +364,16 @@
   context("password",
           po::value<string>(),
           N_("Password to use for auth."));
-  context("db",
+  context("schema",
           po::value<string>(),
-          N_("Default database to use."));
+          N_("Default schema to use."));
 }
 
 DRIZZLE_DECLARE_PLUGIN
 {
   DRIZZLE_VERSION_ID,
   "console",
-  "0.1",
+  "0.2",
   "Eric Day",
   "Console Client",
   PLUGIN_LICENSE_BSD,

=== modified file 'plugin/console/plugin.ini'
--- plugin/console/plugin.ini	2010-09-15 20:24:31 +0000
+++ plugin/console/plugin.ini	2011-01-24 04:10:04 +0000
@@ -1,6 +1,6 @@
 [plugin]
 title=Console Client
 description=Plugin that provides a command console in the drizzled process.
-load_by_default=no
-static=no
+load_by_default=yes
+static=yes
 sources=console.cc

